aboutsummaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorNicola Di Lieto <nicola.dilieto@gmail.com>2020-05-28 08:34:33 +0200
committerNicola Di Lieto <nicola.dilieto@gmail.com>2020-05-28 17:17:27 +0200
commitfde98f7773b15175d8f88fe28ac5b3e42f386077 (patch)
treed715349ef39aaf17f85904fcf9404139ca1551e1 /include
parent6e24980cc6c3bc024ddc114921e593495165a9c4 (diff)
downloadmbedtls-fde98f7773b15175d8f88fe28ac5b3e42f386077.zip
mbedtls-fde98f7773b15175d8f88fe28ac5b3e42f386077.tar.gz
mbedtls-fde98f7773b15175d8f88fe28ac5b3e42f386077.tar.bz2
Rename mbedtls_x509_crt_parse_der_ext
new name: mbedtls_x509_crt_parse_der_with_ext_cb Co-authored-by: Gilles Peskine <gilles.peskine@arm.com> Signed-off-by: Nicola Di Lieto <nicola.dilieto@gmail.com>
Diffstat (limited to 'include')
-rw-r--r--include/mbedtls/x509_crt.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/include/mbedtls/x509_crt.h b/include/mbedtls/x509_crt.h
index 13687b5..96129be 100644
--- a/include/mbedtls/x509_crt.h
+++ b/include/mbedtls/x509_crt.h
@@ -307,8 +307,8 @@ int mbedtls_x509_crt_parse_der( mbedtls_x509_crt *chain,
* \brief The type of certificate extension callbacks.
*
* Callbacks of this type are passed to and used by the
* mbedtls_x509_crt_parse_der_ext() routine when it encounters
* an unsupported extension.
*
* \param crt The certificate being parsed.
* \param oid The OID of the extension.
@@ -354,10 +354,10 @@ typedef int (*mbedtls_x509_crt_ext_cb_t)( mbedtls_x509_crt const *crt,
* \return \c 0 if successful.
* \return A negative error code on failure.
*/
-int mbedtls_x509_crt_parse_der_ext( mbedtls_x509_crt *chain,
- const unsigned char *buf,
- size_t buflen,
- mbedtls_x509_crt_ext_cb_t cb );
+int mbedtls_x509_crt_parse_der_with_ext_cb( mbedtls_x509_crt *chain,
+ const unsigned char *buf,
+ size_t buflen,
+ mbedtls_x509_crt_ext_cb_t cb );
/**
* \brief Parse a single DER formatted certificate and add it
@@ -307,8 +307,8 @@ int mbedtls_x509_crt_parse_der( mbedtls_x509_crt *chain,
*
* Callbacks of this type are passed to and used by the
- * mbedtls_x509_crt_parse_der_ext() routine when it encounters
- * an unsupported extension.
+ * mbedtls_x509_crt_parse_der_with_ext_cb() routine when
+ * it encounters an unsupported extension.
*
* \param crt The certificate being parsed.